.. Copyright 2013-2022 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Web framework
=============

.. toctree::
   :maxdepth: 2

   Core web framework functionality (reahl.web.fw) <fw>
   Low-level Widgets (reahl.web.ui) <ui>
   Generic layout tools (reahl.web.layout) <layout>
   Widgets and Layouts (bootstrap) -- what you'd use to build a user interface that looks like something (reahl.web.bootstrap) <bootstrap/index>
   Plotly charts (reahl.web.plotly) <plotly>
   Holder -- on-the-fly placeholder images (reahl.web.holder) <holder>

   Including not-quite-static static content (reahl.web.dhtml) <dhtml>
   Interfaces for persisted classes of which many implementations can exist (reahl.web.interfaces) <interfaces>
   The declarative implementation (reahl.webdeclarative) <webdeclarative>

   Dealing with JavaScript and CSS code and external libraries (reahl.web.libraries) <libraries>

   Support for making payments via PayPal (reahl.paypalsupport) <paypalsupport>
